==> haskell-genvalidity-1.1.0.0-22-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-genvalidity.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 genvalidity
version:              1.1.0.0
visibility:           public
id:                   genvalidity-1.1.0.0-15FIHR1FHZbCscNBwd1jFE
key:                  genvalidity-1.1.0.0-15FIHR1FHZbCscNBwd1jFE
license:              MIT
copyright:            Copyright: (c) 2016-2021 Tom Sydney Kerckhove
maintainer:           syd@cs-syd.eu
author:               Tom Sydney Kerckhove
homepage:             https://github.com/NorfairKing/validity#readme
synopsis:             Testing utilities for the validity library
description:
    Note: There are companion instance packages for this library:

    * <https://hackage.haskell.org/package/genvalidity-aeson genvalidity-aeson>

    * <https://hackage.haskell.org/package/genvalidity-bytestring genvalidity-bytestring>

    * <https://hackage.haskell.org/package/genvalidity-containers genvalidity-containers>

    * <https://hackage.haskell.org/package/genvalidity-path genvalidity-path>

    * <https://hackage.haskell.org/package/genvalidity-scientific genvalidity-scientific>

    * <https://hackage.haskell.org/package/genvalidity-text genvalidity-text>

    * <https://hackage.haskell.org/package/genvalidity-time genvalidity-time>

    * <https://hackage.haskell.org/package/genvalidity-unordered-containers genvalidity-unordered-containers>

    * <https://hackage.haskell.org/package/genvalidity-uuid genvalidity-uuid>

    * <https://hackage.haskell.org/package/genvalidity-vector genvalidity-vector>

category:             Testing
abi:                  5012a03073e19521d8e9fd0ffff9a5ce
exposed:              True
exposed-modules:      Data.GenValidity Data.GenValidity.Utils
hidden-modules:       Paths_genvalidity
import-dirs:          /usr/lib/ghc-9.0.2/site-local/genvalidity-1.1.0.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/genvalidity-1.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-genvalidity
hs-libraries:         HSgenvalidity-1.1.0.0-15FIHR1FHZbCscNBwd1jFE
depends:
    QuickCheck-2.14.3-4hyQsUnjMY55ypxGhZkEcJ base-4.15.1.0
    random-1.2.1.1-71meI303K8iKpu6Jml2q3U
    validity-0.12.0.1-I24LoB73pGb6XGMStw7UVA

haddock-interfaces:   /usr/share/doc/haskell-genvalidity/html/genvalidity.haddock
haddock-html:         /usr/share/doc/haskell-genvalidity/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-genvalidity-1.1.0.0-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-genvalidity.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 genvalidity
version:              1.1.0.0
visibility:           public
id:                   genvalidity-1.1.0.0-JP7UVawtwRsT6d7TDSCNS
key:                  genvalidity-1.1.0.0-JP7UVawtwRsT6d7TDSCNS
license:              MIT
copyright:            Copyright: (c) 2016-2021 Tom Sydney Kerckhove
maintainer:           syd@cs-syd.eu
author:               Tom Sydney Kerckhove
homepage:             https://github.com/NorfairKing/validity#readme
synopsis:             Testing utilities for the validity library
description:
    Note: There are companion instance packages for this library:

    * <https://hackage.haskell.org/package/genvalidity-aeson genvalidity-aeson>

    * <https://hackage.haskell.org/package/genvalidity-bytestring genvalidity-bytestring>

    * <https://hackage.haskell.org/package/genvalidity-containers genvalidity-containers>

    * <https://hackage.haskell.org/package/genvalidity-path genvalidity-path>

    * <https://hackage.haskell.org/package/genvalidity-scientific genvalidity-scientific>

    * <https://hackage.haskell.org/package/genvalidity-text genvalidity-text>

    * <https://hackage.haskell.org/package/genvalidity-time genvalidity-time>

    * <https://hackage.haskell.org/package/genvalidity-unordered-containers genvalidity-unordered-containers>

    * <https://hackage.haskell.org/package/genvalidity-uuid genvalidity-uuid>

    * <https://hackage.haskell.org/package/genvalidity-vector genvalidity-vector>

category:             Testing
abi:                  19fdf2b8e01024837f0a5c66c2d3c104
exposed:              True
exposed-modules:      Data.GenValidity Data.GenValidity.Utils
hidden-modules:       Paths_genvalidity
import-dirs:          /usr/lib/ghc-9.0.2/site-local/genvalidity-1.1.0.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/genvalidity-1.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-genvalidity
hs-libraries:         HSgenvalidity-1.1.0.0-JP7UVawtwRsT6d7TDSCNS
depends:
    QuickCheck-2.14.3-1OE8Tk6Cvw85tkUdApuCR4 base-4.15.1.0
    random-1.2.1.1-K0OGGZ2RgxUBJhcMzCddDt
    validity-0.12.0.1-70NiO0Z5p6sDLW7olKUEtq

haddock-interfaces:   /usr/share/doc/haskell-genvalidity/html/genvalidity.haddock
haddock-html:         /usr/share/doc/haskell-genvalidity/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
